admcycles: Computation in the tautological ring of the moduli space of curves
==============================================================================

Description
-----------

The SageMath package admcycles offers the possibility to compute in the
tautological ring of the Deligne-Mumford compactification of the moduli space
of curves. Construction for standard generators are provided (psi, kappa and
lambda classes) as well as more advanced algebraic construction (double
ramification cycle, strata of differentials).

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/admcycles/

